@@ -763,11 +763,23 @@ Options -Indexes
         $installCmd = "wp login install --activate --mu --yes";
         $installResult = $this->execWpCli($site['container_name'], $site['user'], $installCmd, $path);
         
-        // If installation fails, try to continue anyway (plugin might already be installed)
-        if (!$installResult['success'] && !strpos($installResult['output'], 'already installed')) {
-            // Only throw error if it's not already installed
-            if (!strpos($installResult['output'], 'already installed') && !strpos($installResult['output'], 'already active')) {
-                throw new Exception("Failed to install login plugin: " . $installResult['output']);
+        // Log the installation attempt for debugging
+        error_log("WP-CLI login plugin install result: " . $installResult['output']);
+        
+        // Check if installation was successful - the companion plugin installation is what matters
+        $output = $installResult['output'];
+        $hasCompanionPlugin = strpos($output, 'Success: Companion plugin installed') !== false;
+        $alreadyInstalled = strpos($output, 'already installed') !== false;
+        $alreadyActive = strpos($output, 'already active') !== false;
+        
+        // If we don't have the companion plugin and it's not already there, that's a real error
+        if (!$hasCompanionPlugin && !$alreadyInstalled && !$alreadyActive) {
+            // Check if the login command itself exists by trying to run it
+            $testCmd = "wp login --help";
+            $testResult = $this->execWpCli($site['container_name'], $site['user'], $testCmd, $path);
+            
+            if (!$testResult['success']) {
+                throw new Exception("WP-CLI login command not available. Please install the wp-cli-login-command package.");
             }
         }
         
