@@ -1053,11 +1053,11 @@ document.addEventListener('DOMContentLoaded', function() {
         // Update loading text based on action
         if (action === 'import') {
             submitBtn.innerHTML = '<i class="fa fa-spinner fa-spin"></i> Analyzing WordPress installation...';
-            // Show additional feedback message
-            showAlert('info', 'Importing WordPress site... This may take a moment while we analyze the existing installation.');
+            // Show processing message immediately
+            showProcessing('Importing WordPress site... This may take a moment while we analyze the existing installation.');
         } else {
             submitBtn.innerHTML = '<i class="fa fa-spinner fa-spin"></i> Installing WordPress...';
-            showAlert('info', 'Installing WordPress... This may take a few minutes to download and configure WordPress.');
+            showProcessing('Installing WordPress... This may take a few minutes to download and configure WordPress.');
         }
         
         fetch('/api/wordpress-ajax.php', {
@@ -1103,6 +1103,9 @@ document.addEventListener('DOMContentLoaded', function() {
     document.getElementById('passwordForm').addEventListener('submit', function(e) {
         e.preventDefault();
         
+        // Show processing message
+        showProcessing('Resetting WordPress admin password...');
+        
         const formData = new FormData(this);
         formData.append('action', 'reset_password');
         
@@ -1145,6 +1148,9 @@ document.addEventListener('DOMContentLoaded', function() {
             return;
         }
         
+        // Show immediate processing message
+        showProcessing('Running search & replace on database...');
+        
         const siteId = document.getElementById('searchReplaceSiteId').value;
         const siteRow = document.querySelector(`tr[data-site-id="${siteId}"]`);
         const container = siteRow.dataset.container;
@@ -1177,6 +1183,9 @@ document.addEventListener('DOMContentLoaded', function() {
     document.getElementById('backupSettingsForm').addEventListener('submit', function(e) {
         e.preventDefault();
         
+        // Show immediate processing message
+        showProcessing('Updating backup settings...');
+        
         const formData = new FormData(this);
         formData.append('action', 'update_backup_settings');
         
@@ -1632,6 +1641,9 @@ function fallbackCopyTextToClipboard(text, button) {
     document.body.removeChild(textArea);
 }
 function createLoginLink(siteId) {
+    // Show immediate processing message
+    showProcessing('Creating auto-login link...');
+    
     const formData = new FormData();
     formData.append('action', 'create_login');
     formData.append('site_id', siteId);
@@ -1648,14 +1660,14 @@ function createLoginLink(siteId) {
         if (data.success) {
             // Open login URL in new tab
             window.open(data.login_url, '_blank');
-            showAlert('Login link created and opened in new tab. Expires at: ' + data.expires_at, 'success');
+            showAlert('success', 'Login link created and opened in new tab. Expires at: ' + data.expires_at);
         } else {
-            showAlert('Error creating login link: ' + (data.message || 'Unknown error'), 'danger');
+            showAlert('danger', 'Error creating login link: ' + (data.message || 'Unknown error'));
         }
     })
     .catch(error => {
         console.error('Error creating login link:', error);
-        showAlert('Error creating login link', 'danger');
+        showAlert('danger', 'Error creating login link');
     });
 }
 
@@ -1846,6 +1858,9 @@ function removeFromManagement(siteId) {
         return;
     }
     
+    // Show immediate processing message
+    showProcessing('Removing site from WordPress management...');
+    
     const formData = new FormData();
     formData.append('action', 'remove_from_management');
     formData.append('site_id', siteId);
@@ -1860,18 +1875,18 @@ function removeFromManagement(siteId) {
     .then(response => response.json())
     .then(data => {
         if (data.success) {
-            showAlert('WordPress site removed from management successfully', 'success');
+            showAlert('success', 'WordPress site removed from management successfully');
             // Reload the page to update the sites list
             setTimeout(() => {
                 window.location.reload();
             }, 1500);
         } else {
-            showAlert('Error removing site from management: ' + (data.error || 'Unknown error'), 'danger');
+            showAlert('danger', 'Error removing site from management: ' + (data.error || 'Unknown error'));
         }
     })
     .catch(error => {
         console.error('Error removing from management:', error);
-        showAlert('Error removing site from management', 'danger');
+        showAlert('danger', 'Error removing site from management');
     });
 }
 
@@ -1928,6 +1943,21 @@ function showAlert(type, message, autoDismiss = true) {
     // Remove on close button click
     alertDiv.querySelector('.btn-close').addEventListener('click', removeAlert);
 }
+
+// Helper function to show processing/working messages
+function showProcessing(message) {
+    clearAlerts(); // Clear any existing alerts
+    const processingHtml = `<i class="fa fa-spinner fa-spin me-2"></i><strong>Processing...</strong><br>${message}`;
+    return showAlert('info', processingHtml, false); // Don't auto-dismiss processing messages
+}
+
+// Helper function to clear all alerts
+function clearAlerts() {
+    const alertContainer = document.getElementById('alert-container');
+    if (alertContainer) {
+        alertContainer.innerHTML = '';
+    }
+}
 </script>
 
 <style>
@@ -1967,6 +1997,31 @@ function showAlert(type, message, autoDismiss = true) {
     animation: slideInRight 0.3s ease-out;
 }
 
+/* Ensure background colors for different alert types */
+.floating-alert.alert-success {
+    background-color: #d1e7dd;
+    color: #0f5132;
+    border-color: #badbcc;
+}
+
+.floating-alert.alert-danger {
+    background-color: #f8d7da;
+    color: #842029;
+    border-color: #f5c2c7;
+}
+
+.floating-alert.alert-warning {
+    background-color: #fff3cd;
+    color: #664d03;
+    border-color: #ffecb5;
+}
+
+.floating-alert.alert-info {
+    background-color: #cff4fc;
+    color: #055160;
+    border-color: #b6effb;
+}
+
 /* Animation for alerts sliding in */
 @keyframes slideInRight {
     from {
